import { GetServerSideProps, NextComponentType, NextPageContext } from "next";
import Head from "next/head";
import { dehydrate, QueryClient, useQuery } from "react-query";

import Pagination from "../../components/common/Pagination";
import { List } from "../../components/nombreventes/List";
import { PagedCollection } from "../../types/collection";
import { NombreVentes } from "../../types/NombreVentes";
import { fetch, FetchResponse } from "../../utils/dataAccess";
import { useMercure } from "../../utils/mercure";

const getNombreVentess = async () =>
  await fetch<PagedCollection<NombreVentes>>("/ventes/nombre");

const Page: NextComponentType<NextPageContext> = () => {
  const { data: { data: nombreventess, hubURL } = { hubURL: null } } = useQuery<
    FetchResponse<PagedCollection<NombreVentes>> | undefined
  >("ventes/nombre", getNombreVentess);
  const collection = useMercure(nombreventess, hubURL);

  if (!collection || !collection["hydra:member"]) return null;

  return (
    <div>
      <div>
        <Head>
          <title>NombreVentes List</title>
        </Head>
      </div>
      <List nombreventess={collection["hydra:member"]} />
      <Pagination collection={collection} />
    </div>
  );
};

export const getServerSideProps: GetServerSideProps = async () => {
  const queryClient = new QueryClient();
  await queryClient.prefetchQuery("ventes/nombre", getNombreVentess);

  return {
    props: {
      dehydratedState: dehydrate(queryClient),
    },
  };
};

export default Page;
