import {
  GetStaticPaths,
  GetStaticProps,
  NextComponentType,
  NextPageContext,
} from "next";
import DefaultErrorPage from "next/error";
import Head from "next/head";
import { useRouter } from "next/router";
import { dehydrate, QueryClient, useQuery } from "react-query";

import { Show } from "../../../components/prixmoyen/Show";
import { PagedCollection } from "../../../types/collection";
import { PrixMoyen } from "../../../types/PrixMoyen";
import { fetch, FetchResponse, getPaths } from "../../../utils/dataAccess";
import { useMercure } from "../../../utils/mercure";

const getPrixMoyen = async (id: string | string[] | undefined) =>
  id
    ? await fetch<PrixMoyen>(`/ventes/prix/${id}`)
    : Promise.resolve(undefined);

const Page: NextComponentType<NextPageContext> = () => {
  const router = useRouter();
  const { id } = router.query;

  const {
    data: { data: prixmoyen, hubURL, text } = { hubURL: null, text: "" },
  } = useQuery<FetchResponse<PrixMoyen> | undefined>(["prixmoyen", id], () =>
    getPrixMoyen(id)
  );
  const prixmoyenData = useMercure(prixmoyen, hubURL);

  if (!prixmoyenData) {
    return <DefaultErrorPage statusCode={404} />;
  }

  return (
    <div>
      <div>
        <Head>
          <title>{`Show PrixMoyen ${prixmoyenData["@id"]}`}</title>
        </Head>
      </div>
      <Show prixmoyen={prixmoyenData} text={text} />
    </div>
  );
};

export const getStaticProps: GetStaticProps = async ({
  params: { id } = {},
}) => {
  if (!id) throw new Error("id not in query param");
  const queryClient = new QueryClient();
  await queryClient.prefetchQuery(["prixmoyen", id], () => getPrixMoyen(id));

  return {
    props: {
      dehydratedState: dehydrate(queryClient),
    },
    revalidate: 1,
  };
};

export const getStaticPaths: GetStaticPaths = async () => {
  const response = await fetch<PagedCollection<PrixMoyen>>("/ventes/prix");
  const paths = await getPaths(response, "ventes/prix", "/prixmoyens/[id]");

  return {
    paths,
    fallback: true,
  };
};

export default Page;
