import { GetServerSideProps, NextComponentType, NextPageContext } from "next";
import Head from "next/head";
import { dehydrate, QueryClient, useQuery } from "react-query";

import Pagination from "../../components/common/Pagination";
import { List } from "../../components/prixmoyen/List";
import { PagedCollection } from "../../types/collection";
import { PrixMoyen } from "../../types/PrixMoyen";
import { fetch, FetchResponse } from "../../utils/dataAccess";
import { useMercure } from "../../utils/mercure";

const getPrixMoyens = async () =>
  await fetch<PagedCollection<PrixMoyen>>("/ventes/prix");

const Page: NextComponentType<NextPageContext> = () => {
  const { data: { data: prixmoyens, hubURL } = { hubURL: null } } = useQuery<
    FetchResponse<PagedCollection<PrixMoyen>> | undefined
  >("ventes/prix", getPrixMoyens);
  const collection = useMercure(prixmoyens, hubURL);

  if (!collection || !collection["hydra:member"]) return null;

  return (
    <div>
      <div>
        <Head>
          <title>PrixMoyen List</title>
        </Head>
      </div>
      <List prixmoyens={collection["hydra:member"]} />
      <Pagination collection={collection} />
    </div>
  );
};

export const getServerSideProps: GetServerSideProps = async () => {
  const queryClient = new QueryClient();
  await queryClient.prefetchQuery("ventes/prix", getPrixMoyens);

  return {
    props: {
      dehydratedState: dehydrate(queryClient),
    },
  };
};

export default Page;
