import { GetServerSideProps, NextComponentType, NextPageContext } from "next";
import Head from "next/head";
import { dehydrate, QueryClient, useQuery } from "react-query";

import Pagination from "../../components/common/Pagination";
import { List } from "../../components/regionventes/List";
import { PagedCollection } from "../../types/collection";
import { RegionVentes } from "../../types/RegionVentes";
import { fetch, FetchResponse } from "../../utils/dataAccess";
import { useMercure } from "../../utils/mercure";

const getRegionVentess = async () =>
  await fetch<PagedCollection<RegionVentes>>("/ventes/regions");

const Page: NextComponentType<NextPageContext> = () => {
  const { data: { data: regionventess, hubURL } = { hubURL: null } } = useQuery<
    FetchResponse<PagedCollection<RegionVentes>> | undefined
  >("ventes/regions", getRegionVentess);
  const collection = useMercure(regionventess, hubURL);

  if (!collection || !collection["hydra:member"]) return null;

  return (
    <div>
      <div>
        <Head>
          <title>RegionVentes List</title>
        </Head>
      </div>
      <List regionventess={collection["hydra:member"]} />
      <Pagination collection={collection} />
    </div>
  );
};

export const getServerSideProps: GetServerSideProps = async () => {
  const queryClient = new QueryClient();
  await queryClient.prefetchQuery("ventes/regions", getRegionVentess);

  return {
    props: {
      dehydratedState: dehydrate(queryClient),
    },
  };
};

export default Page;
