import { GetServerSideProps, NextComponentType, NextPageContext } from "next";
import Head from "next/head";
import { dehydrate, QueryClient, useQuery } from "react-query";

import Pagination from "../../components/common/Pagination";
import { List } from "../../components/vente/List";
import { PagedCollection } from "../../types/collection";
import { Vente } from "../../types/Vente";
import { fetch, FetchResponse } from "../../utils/dataAccess";
import { useMercure } from "../../utils/mercure";

const getVentes = async () => await fetch<PagedCollection<Vente>>("/ventes");

const Page: NextComponentType<NextPageContext> = () => {
  const { data: { data: ventes, hubURL } = { hubURL: null } } = useQuery<
    FetchResponse<PagedCollection<Vente>> | undefined
  >("ventes", getVentes);
  const collection = useMercure(ventes, hubURL);

  if (!collection || !collection["hydra:member"]) return null;

  return (
    <div>
      <div>
        <Head>
          <title>Vente List</title>
        </Head>
      </div>
      <List ventes={collection["hydra:member"]} />
      <Pagination collection={collection} />
    </div>
  );
};

export const getServerSideProps: GetServerSideProps = async () => {
  const queryClient = new QueryClient();
  await queryClient.prefetchQuery("ventes", getVentes);

  return {
    props: {
      dehydratedState: dehydrate(queryClient),
    },
  };
};

export default Page;
